@@ -6,7 +6,8 @@ from __future__ import with_statement
 try:
     from inspect import getcallargs, getargspec
 except ImportError:
-    from rpcpdb.inspect_helper import getcallargs, getargspec
+    # more support for older (2.x) Python versions...
+    from rpcpdb.inspect_helper import getcallargs, getargspec  # NOQA
 
 import pdb
 import socket
@@ -77,13 +78,14 @@ class UPdb_mixin(object):
     # (function, unix_socket_path) pairs.
     _updb_debug_func = {}
 
-    def debug_func(self, f, once=True, force=True, match_criteria=None):
+    def debug_func(self, f, once=True, force=True,
+                   match_criteria=None, ignore_count=0):
         """
         @param f: function name
-        @param once: one-shot debug - undebug after first hit (default True)
-        @param force: override any existing unix socket (default True)
-        @param match_criteria: optional dictionary mapping parameter names
-            to values; checked prior to debug
+        @param once: one-shot debug - undebug after first hit
+        @param force: override any existing unix socket
+        @param match_criteria: dictionary of param name/value matches
+        @param ignore_count: don't trigger for ignore_count matches
         @return: path to debug socket
         """
         if f in self._updb_debug_func:
@@ -118,16 +120,21 @@ class UPdb_mixin(object):
 
                 return match
 
-            def _(*o, **k):
+            def debug_check(*o, **k):
                 if arg_match(o, k):
-                    if once:
-                        self.undebug_func(f)
-                    with UPdb(pdb_sock_path, level=1, force=force):
-                        return func(*o, **k)
-                else:
-                    # we're not debugging you, this time...
-                    return func(*o, **k)
-            setattr(self, f, _)
+                    if debug_check._ignore_count <= 0:
+                        if once:
+                            self.undebug_func(f)
+                        with UPdb(pdb_sock_path, level=1, force=force):
+                            return func(*o, **k)
+                    debug_check._ignore_count -= 1
+                # we're not debugging you, this time...
+                return func(*o, **k)
+            # use a function attribute to store the skip count;
+            # decrement this on each matched call. Trigger at <= 0
+            debug_check._ignore_count = ignore_count
+
+            setattr(self, f, debug_check)
             return pdb_sock_path
 
     def undebug_func(self, f):
