@@ -5,10 +5,10 @@ import time
 
 s = xmlrpclib.ServerProxy('http://localhost:8000')
 # Print list of available methods
-print s.system.listMethods()
+print(s.system.listMethods())
 
 p = 0
 while True:
     time.sleep(0.5)
     p = s.next_prime(p)
-    print p
+    print(p)
